@@ -1,7 +1,7 @@
 from tqdm import *
 from time import sleep
 from random import randint,choice
-from os import system
+from os import system,urandom
 from termcolor import colored
 import f61d.LOGO as LOGO
 
@@ -10,12 +10,13 @@ print(colored("Welcome to F61D. Use Help() for help.",'green'))
 
 help_cont = {}
 help_cont[0] = 'Help     : See this help page'
-help_cont[1] = 'fuckstar : One Button to fuck Satellite'
+help_cont[1] = 'fuckStar : One Button to fuck Satellite'
 help_cont[2] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
 help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
 help_cont[6] = 'Nim      : An interesting turtle game.'
+help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
 
 def Help(page=1,lines = 5):
     maxPage = int((0.5+len(help_cont))/lines)+1
@@ -34,12 +35,15 @@ def Help(page=1,lines = 5):
 
 
 def fuckStar():
-    print('欢迎使用一键日卫星功能')
-    print('请输入要日的卫星编号(可在官网查询):',end='')
+    print(' - 欢迎使用一键日卫星功能')
+    print(' - 请输入要日的卫星编号(可在官网查询):',end='')
     num = input()
     while num == '':
         num = input('请重新输入：')
-    for i in trange(randint(1000,2000)):
+
+    bar = trange(randint(1000,2000))
+    for i in bar:
+        bar.set_description('Hacking:',hex(urandom(4))[2:])
         for _ in range(66666):
             a = 1
             b = 1
@@ -47,7 +51,13 @@ def fuckStar():
     for i in range(3):
         print('.',end='')
         sleep(0.4)
-    print(colored('\n日卫星失败，请重新尝试','red'))
+    if randint(1,100) > 80 or num == 'CHY':
+        for i in range(3):
+            print(colored('.','green'),end='')
+            sleep(0.4)
+        print(colored('\n日卫星成功.','green'))    
+    else:
+        print(colored('\n日卫星失败，请重新尝试','red'))
     
 def lifeGame():
     from f61d.lifeGame import game
@@ -117,9 +127,10 @@ def prove(cont):
         if ss(S+a) == b:
             print('Find ,',S)
             return S
+
     
-        
-        
+def getLogo():
+    print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
     
     
 def main():
